@@ -183,6 +183,7 @@ class Feature:
             *,
             start: Timestamp = None,
             end: Timestamp = None,
+            root: str = None,
     ) -> pd.DataFrame:
         r"""Extract features from an audio file.
 
@@ -192,13 +193,19 @@ class Feature:
                 If value is as a float or integer it is treated as seconds
             end: end processing at this position.
                 If value is as a float or integer it is treated as seconds
+            root: root folder to expand relative file path
 
         Raises:
             RuntimeError: if sampling rates do not match
             RuntimeError: if channel selection is invalid
 
         """
-        series = self.process.process_file(file, start=start, end=end)
+        series = self.process.process_file(
+            file,
+            start=start,
+            end=end,
+            root=root,
+        )
         return self._series_to_frame(series)
 
     def process_files(
@@ -207,6 +214,7 @@ class Feature:
             *,
             starts: Timestamps = None,
             ends: Timestamps = None,
+            root: str = None,
     ) -> pd.DataFrame:
         r"""Extract features for a list of files.
 
@@ -218,13 +226,19 @@ class Feature:
             ends: segment end positions.
                 Time values given as float or integers are treated as seconds
                 If a scalar is given, it is applied to all files
+            root: root folder to expand relative file paths
 
         Raises:
             RuntimeError: if sampling rates do not match
             RuntimeError: if channel selection is invalid
 
         """
-        series = self.process.process_files(files, starts=starts, ends=ends)
+        series = self.process.process_files(
+            files,
+            starts=starts,
+            ends=ends,
+            root=root,
+        )
         return self._series_to_frame(series)
 
     def process_folder(
@@ -253,11 +267,14 @@ class Feature:
     def process_index(
             self,
             index: pd.Index,
+            *,
+            root: str = None,
     ) -> pd.DataFrame:
         r"""Extract features from an index conform to audformat_.
 
         Args:
             index: index with segment information
+            root: root folder to expand relative file paths
 
         Raises:
             RuntimeError: if sampling rates do not match
@@ -267,7 +284,7 @@ class Feature:
         .. _audformat: https://audeering.github.io/audformat/data-format.html
 
         """
-        series = self.process.process_index(index)
+        series = self.process.process_index(index, root=root)
         return self._series_to_frame(series)
 
     def process_signal(
